@@ -1,6 +1,3 @@
-
-# Random forest -----------------------------------------------------------
-
 #' Implemented regression methods
 #' @rdname regressions
 #' @param y Vector (or matrix) of response values.
@@ -34,7 +31,9 @@
 rf <- function(y, x, ...) {
   args <- list(...)
   if (length(unique(y)) == 2) {
-    y <- as.factor(y)
+    y <- factor(y)
+  }
+  if (is.factor(y)) {
     args$probability <- TRUE
   }
   rf <- do.call("ranger", c(list(y = y, x = x), args))
@@ -46,17 +45,32 @@ rf <- function(y, x, ...) {
 predict.rf <- function(object, data = NULL, ...) {
   class(object) <- class(object)[-1]
   preds <- predict(object, data = data)$predictions
-  if (object$treetype == "Probability estimation")
-    preds <- preds[, 2]
+  if (object$treetype == "Probability estimation") {
+    preds <- preds[, -1]
+  }
   preds
 }
 
 #' @exportS3Method residuals rf
 residuals.rf <- function(object, response = NULL, data = NULL, ...) {
   preds <- predict.rf(object, data, ...)
+  if (length(unique(response)) == 2) {
+    response <- factor(response)
+  }
   .compute_residuals(response, preds)
 }
 
+### Internal residuals function dealing with factors
+#' @importFrom stats model.matrix model.frame predict
+.compute_residuals <- function(y, pred) {
+  if (is.factor(y)) {
+    y <- stats::model.matrix(~ 0 + y,
+      contrasts.arg = list("y" = "contr.treatment")
+    )[, -1]
+  }
+  y - pred
+}
+
 ### Survival forest
 #' @rdname regressions
 survforest <- function(y, x, ...) {
@@ -127,6 +141,28 @@ residuals.lrm <- function(object, response = NULL, data = NULL, ...) {
   .compute_residuals(response, preds)
 }
 
+#' @rdname regressions
+#' @importFrom stats glm
+glrm <- function(y, x, ...) {
+  dat <- list(y = y, x = x)
+  obj <- stats::glm(y ~ x, data = dat, ...)
+  class(obj) <- c("glrm", class(obj))
+  obj
+}
+
+#' @exportS3Method predict glrm
+predict.glrm <- function(object, data = NULL, ...) {
+  class(object) <- class(object)[-1]
+  predict(object, newdata = list(x = data), ...)
+}
+
+#' @exportS3Method residuals glrm
+#' @importFrom stats residuals
+residuals.glrm <- function(object, response = NULL, data = NULL, ...) {
+  preds <- predict(object, data = data, type = "response")
+  .compute_residuals(response, preds)
+}
+
 #' @importFrom glmnet cv.glmnet
 #' @rdname regressions
 lasso <- function(y, x, ...) {
@@ -158,8 +194,11 @@ ridge <- function(y, x, ...) {
 postlasso <- function(y, x, ...) {
   obj <- cv.glmnet(y = y, x = as.matrix(x), ...)
   nz <- which(stats::coef(obj, s = "lambda.1se")[-1] != 0)
-  obj <- if (!identical(nz, integer(0))) stats::lm(y ~ x[, nz]) else
+  obj <- if (!identical(nz, integer(0))) {
+    stats::lm(y ~ x[, nz])
+  } else {
     stats::lm(y ~ 1)
+  }
   obj$nz <- nz
   class(obj) <- c("postlasso", class(obj))
   obj
